
# -*- coding: utf-8 -*-
"""
DO NOT EDIT THIS FILE!
It is automatically generated from opcfoundation.org schemas.
"""

from opcua import ua


def create_standard_address_space_Part3(server):
  
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3062")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=58")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The default binary encoding for a data type.")
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3063")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.TypeDefinition = ua.NodeId.from_string("i=58")
    attrs = ua.ObjectAttributes()
    attrs.Description = ua.LocalizedText("The default XML encoding for a data type.")
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3063")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=58")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=24")
    node.BrowseName = ua.QualifiedName.from_string("BaseDataType")
    node.NodeClass = ua.NodeClass.DataType
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that can have any valid DataType.")
    attrs.DisplayName = ua.LocalizedText("BaseDataType")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=26")
    node.BrowseName = ua.QualifiedName.from_string("Number")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that can have any numeric DataType.")
    attrs.DisplayName = ua.LocalizedText("Number")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=26")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=27")
    node.BrowseName = ua.QualifiedName.from_string("Integer")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=26")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that can have any integer DataType.")
    attrs.DisplayName = ua.LocalizedText("Integer")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=27")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=26")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=28")
    node.BrowseName = ua.QualifiedName.from_string("UInteger")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=26")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that can have any unsigned integer DataType.")
    attrs.DisplayName = ua.LocalizedText("UInteger")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=28")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=26")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=29")
    node.BrowseName = ua.QualifiedName.from_string("Enumeration")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an enumerated DataType.")
    attrs.DisplayName = ua.LocalizedText("Enumeration")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=29")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=1")
    node.BrowseName = ua.QualifiedName.from_string("Boolean")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is either TRUE or FALSE.")
    attrs.DisplayName = ua.LocalizedText("Boolean")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=1")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2")
    node.BrowseName = ua.QualifiedName.from_string("SByte")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=27")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between -128 and 127.")
    attrs.DisplayName = ua.LocalizedText("SByte")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=27")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3")
    node.BrowseName = ua.QualifiedName.from_string("Byte")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=28")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between 0 and 255.")
    attrs.DisplayName = ua.LocalizedText("Byte")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=3")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=28")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=4")
    node.BrowseName = ua.QualifiedName.from_string("Int16")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=27")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between −32,768 and 32,767.")
    attrs.DisplayName = ua.LocalizedText("Int16")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=4")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=27")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=5")
    node.BrowseName = ua.QualifiedName.from_string("UInt16")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=28")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between 0 and 65535.")
    attrs.DisplayName = ua.LocalizedText("UInt16")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=5")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=28")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=6")
    node.BrowseName = ua.QualifiedName.from_string("Int32")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=27")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between −2,147,483,648  and 2,147,483,647.")
    attrs.DisplayName = ua.LocalizedText("Int32")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=6")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=27")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7")
    node.BrowseName = ua.QualifiedName.from_string("UInt32")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=28")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between 0 and 4,294,967,295.")
    attrs.DisplayName = ua.LocalizedText("UInt32")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=7")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=28")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8")
    node.BrowseName = ua.QualifiedName.from_string("Int64")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=27")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between −9,223,372,036,854,775,808 and 9,223,372,036,854,775,807.")
    attrs.DisplayName = ua.LocalizedText("Int64")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=8")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=27")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=9")
    node.BrowseName = ua.QualifiedName.from_string("UInt64")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=28")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an integer between 0 and 18,446,744,073,709,551,615.")
    attrs.DisplayName = ua.LocalizedText("UInt64")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=9")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=28")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=10")
    node.BrowseName = ua.QualifiedName.from_string("Float")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=26")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an IEEE 754-1985 single precision floating point number.")
    attrs.DisplayName = ua.LocalizedText("Float")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=10")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=26")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11")
    node.BrowseName = ua.QualifiedName.from_string("Double")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=26")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an IEEE 754-1985 double precision floating point number.")
    attrs.DisplayName = ua.LocalizedText("Double")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=11")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=26")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12")
    node.BrowseName = ua.QualifiedName.from_string("String")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a sequence of printable Unicode characters.")
    attrs.DisplayName = ua.LocalizedText("String")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=13")
    node.BrowseName = ua.QualifiedName.from_string("DateTime")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a Gregorian calender date and time.")
    attrs.DisplayName = ua.LocalizedText("DateTime")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=13")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14")
    node.BrowseName = ua.QualifiedName.from_string("Guid")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a 128-bit globally unique identifier.")
    attrs.DisplayName = ua.LocalizedText("Guid")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=14")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15")
    node.BrowseName = ua.QualifiedName.from_string("ByteString")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a sequence of bytes.")
    attrs.DisplayName = ua.LocalizedText("ByteString")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16")
    node.BrowseName = ua.QualifiedName.from_string("XmlElement")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an XML element.")
    attrs.DisplayName = ua.LocalizedText("XmlElement")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=16")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=17")
    node.BrowseName = ua.QualifiedName.from_string("NodeId")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an identifier for a node within a Server address space.")
    attrs.DisplayName = ua.LocalizedText("NodeId")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=17")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=20")
    node.BrowseName = ua.QualifiedName.from_string("QualifiedName")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is a name qualified by a namespace.")
    attrs.DisplayName = ua.LocalizedText("QualifiedName")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=20")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=21")
    node.BrowseName = ua.QualifiedName.from_string("LocalizedText")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is human readable Unicode text with a locale identifier.")
    attrs.DisplayName = ua.LocalizedText("LocalizedText")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=21")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=22")
    node.BrowseName = ua.QualifiedName.from_string("Structure")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=24")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is any type of structure that can be described with a data encoding.")
    attrs.DisplayName = ua.LocalizedText("Structure")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=22")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=24")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=30")
    node.BrowseName = ua.QualifiedName.from_string("Image")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=15")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that is an image encoded as a string of bytes.")
    attrs.DisplayName = ua.LocalizedText("Image")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=30")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=50")
    node.BrowseName = ua.QualifiedName.from_string("Decimal")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=26")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes an arbitrary precision decimal value.")
    attrs.DisplayName = ua.LocalizedText("Decimal")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=50")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=26")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=31")
    node.BrowseName = ua.QualifiedName.from_string("References")
    node.NodeClass = ua.NodeClass.ReferenceType
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The abstract base type for all references.")
    attrs.DisplayName = ua.LocalizedText("References")
    attrs.IsAbstract = True
    attrs.Symmetric = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=32")
    node.BrowseName = ua.QualifiedName.from_string("NonHierarchicalReferences")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=31")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The abstract base type for all non-hierarchical references.")
    attrs.DisplayName = ua.LocalizedText("NonHierarchicalReferences")
    attrs.InverseName = ua.LocalizedText("NonHierarchicalReferences")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=32")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=31")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=33")
    node.BrowseName = ua.QualifiedName.from_string("HierarchicalReferences")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=31")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The abstract base type for all hierarchical references.")
    attrs.DisplayName = ua.LocalizedText("HierarchicalReferences")
    attrs.InverseName = ua.LocalizedText("HierarchicalReferences")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=33")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=31")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=34")
    node.BrowseName = ua.QualifiedName.from_string("HasChild")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=33")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The abstract base type for all non-looping hierarchical references.")
    attrs.DisplayName = ua.LocalizedText("HasChild")
    attrs.InverseName = ua.LocalizedText("ChildOf")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=34")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=33")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=35")
    node.BrowseName = ua.QualifiedName.from_string("Organizes")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=33")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for hierarchical references that are used to organize nodes.")
    attrs.DisplayName = ua.LocalizedText("Organizes")
    attrs.InverseName = ua.LocalizedText("OrganizedBy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=35")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=33")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=36")
    node.BrowseName = ua.QualifiedName.from_string("HasEventSource")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=33")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical references that are used to organize event sources.")
    attrs.DisplayName = ua.LocalizedText("HasEventSource")
    attrs.InverseName = ua.LocalizedText("EventSourceOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=36")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=33")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=37")
    node.BrowseName = ua.QualifiedName.from_string("HasModellingRule")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for references from instance declarations to modelling rule nodes.")
    attrs.DisplayName = ua.LocalizedText("HasModellingRule")
    attrs.InverseName = ua.LocalizedText("ModellingRuleOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=37")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=38")
    node.BrowseName = ua.QualifiedName.from_string("HasEncoding")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for references from data type nodes to to data type encoding nodes.")
    attrs.DisplayName = ua.LocalizedText("HasEncoding")
    attrs.InverseName = ua.LocalizedText("EncodingOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=38")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=39")
    node.BrowseName = ua.QualifiedName.from_string("HasDescription")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for references from data type encoding nodes to data type description nodes.")
    attrs.DisplayName = ua.LocalizedText("HasDescription")
    attrs.InverseName = ua.LocalizedText("DescriptionOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=39")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=40")
    node.BrowseName = ua.QualifiedName.from_string("HasTypeDefinition")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for references from a instance node its type defintion node.")
    attrs.DisplayName = ua.LocalizedText("HasTypeDefinition")
    attrs.InverseName = ua.LocalizedText("TypeDefinitionOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=40")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=41")
    node.BrowseName = ua.QualifiedName.from_string("GeneratesEvent")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=32")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for references from a node to an event type that is raised by node.")
    attrs.DisplayName = ua.LocalizedText("GeneratesEvent")
    attrs.InverseName = ua.LocalizedText("GeneratedBy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=41")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=32")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3065")
    node.BrowseName = ua.QualifiedName.from_string("AlwaysGeneratesEvent")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=41")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for references from a node to an event type that is always raised by node.")
    attrs.DisplayName = ua.LocalizedText("AlwaysGeneratesEvent")
    attrs.InverseName = ua.LocalizedText("AlwaysGeneratedBy")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=3065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=41")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=44")
    node.BrowseName = ua.QualifiedName.from_string("Aggregates")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=34")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical references that are used to aggregate nodes into complex types.")
    attrs.DisplayName = ua.LocalizedText("Aggregates")
    attrs.InverseName = ua.LocalizedText("AggregatedBy")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=44")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=34")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=45")
    node.BrowseName = ua.QualifiedName.from_string("HasSubtype")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=34")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical references that are used to define sub types.")
    attrs.DisplayName = ua.LocalizedText("HasSubtype")
    attrs.InverseName = ua.LocalizedText("SubtypeOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=45")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=34")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=46")
    node.BrowseName = ua.QualifiedName.from_string("HasProperty")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=44")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical reference from a node to its property.")
    attrs.DisplayName = ua.LocalizedText("HasProperty")
    attrs.InverseName = ua.LocalizedText("PropertyOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=46")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=44")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=47")
    node.BrowseName = ua.QualifiedName.from_string("HasComponent")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=44")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical reference from a node to its component.")
    attrs.DisplayName = ua.LocalizedText("HasComponent")
    attrs.InverseName = ua.LocalizedText("ComponentOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=47")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=44")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=48")
    node.BrowseName = ua.QualifiedName.from_string("HasNotifier")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=36")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical references that are used to indicate how events propagate from node to node.")
    attrs.DisplayName = ua.LocalizedText("HasNotifier")
    attrs.InverseName = ua.LocalizedText("NotifierOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=48")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=36")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=49")
    node.BrowseName = ua.QualifiedName.from_string("HasOrderedComponent")
    node.NodeClass = ua.NodeClass.ReferenceType
    node.ParentNodeId = ua.NodeId.from_string("i=47")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.ReferenceTypeAttributes()
    attrs.Description = ua.LocalizedText("The type for non-looping hierarchical reference from a node to its component when the order of references matters.")
    attrs.DisplayName = ua.LocalizedText("HasOrderedComponent")
    attrs.InverseName = ua.LocalizedText("OrderedComponentOf")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=49")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=47")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=120")
    node.BrowseName = ua.QualifiedName.from_string("NamingRuleType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("Describes a value that specifies the significance of the BrowseName for an instance declaration.")
    attrs.DisplayName = ua.LocalizedText("NamingRuleType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12169")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=120")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12169")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=120")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    value = []
    extobj = ua.EnumValueType()
    extobj.Value = 1
    extobj.DisplayName.Text = 'Mandatory'
    extobj.Description.Text = 'The BrowseName must appear in all instances of the type.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2
    extobj.DisplayName.Text = 'Optional'
    extobj.Description.Text = 'The BrowseName may appear in an instance of the type.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 3
    extobj.DisplayName.Text = 'Constraint'
    extobj.Description.Text = 'The modelling rule defines a constraint and the BrowseName is not used in an instance of the type.'
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=12169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=12169")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=120")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3068")
    node.BrowseName = ua.QualifiedName.from_string("NodeVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The version number of the node (used to indicate changes to references of the owning node).")
    attrs.DisplayName = ua.LocalizedText("NodeVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3068")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12170")
    node.BrowseName = ua.QualifiedName.from_string("ViewVersion")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The version number of the view.")
    attrs.DisplayName = ua.LocalizedText("ViewVersion")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12170")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3067")
    node.BrowseName = ua.QualifiedName.from_string("Icon")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("A small image representing the object.")
    attrs.DisplayName = ua.LocalizedText("Icon")
    attrs.DataType = ua.NodeId.from_string("i=30")
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3067")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3069")
    node.BrowseName = ua.QualifiedName.from_string("LocalTime")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The local time where the owning variable value was collected.")
    attrs.DisplayName = ua.LocalizedText("LocalTime")
    attrs.DataType = ua.NodeId.from_string("i=8912")
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3069")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3070")
    node.BrowseName = ua.QualifiedName.from_string("AllowNulls")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Whether the value of the owning variable is allowed to be null.")
    attrs.DisplayName = ua.LocalizedText("AllowNulls")
    attrs.DataType = ua.NodeId(ua.ObjectIds.Boolean)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3070")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11433")
    node.BrowseName = ua.QualifiedName.from_string("ValueAsText")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The string representation of the current value for a variable with an enumerated data type.")
    attrs.DisplayName = ua.LocalizedText("ValueAsText")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11433")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11498")
    node.BrowseName = ua.QualifiedName.from_string("MaxStringLength")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of bytes supported by the DataVariable.")
    attrs.DisplayName = ua.LocalizedText("MaxStringLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11498")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15002")
    node.BrowseName = ua.QualifiedName.from_string("MaxCharacters")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum number of Unicode characters supported by the DataVariable.")
    attrs.DisplayName = ua.LocalizedText("MaxCharacters")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15002")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12908")
    node.BrowseName = ua.QualifiedName.from_string("MaxByteStringLength")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for a byte string that can be stored in the owning variable.")
    attrs.DisplayName = ua.LocalizedText("MaxByteStringLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12908")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11512")
    node.BrowseName = ua.QualifiedName.from_string("MaxArrayLength")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The maximum length for an array that can be stored in the owning variable.")
    attrs.DisplayName = ua.LocalizedText("MaxArrayLength")
    attrs.DataType = ua.NodeId(ua.ObjectIds.UInt32)
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11512")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11513")
    node.BrowseName = ua.QualifiedName.from_string("EngineeringUnits")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The engineering units for the value of the owning variable.")
    attrs.DisplayName = ua.LocalizedText("EngineeringUnits")
    attrs.DataType = ua.NodeId.from_string("i=887")
    attrs.ValueRank = -2
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11513")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11432")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The human readable strings associated with the values of an enumerated value (when values are sequential).")
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11432")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3071")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The human readable strings associated with the values of an enumerated value (when values have no sequence).")
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3071")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12745")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Contains the human-readable representation for each bit of the bit mask.")
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12745")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3072")
    node.BrowseName = ua.QualifiedName.from_string("InputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The input arguments for a method.")
    attrs.DisplayName = ua.LocalizedText("InputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3072")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=3073")
    node.BrowseName = ua.QualifiedName.from_string("OutputArguments")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("The output arguments for a method.")
    attrs.DisplayName = ua.LocalizedText("OutputArguments")
    attrs.DataType = ua.NodeId.from_string("i=296")
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=3073")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16306")
    node.BrowseName = ua.QualifiedName.from_string("DefaultInputValues")
    node.NodeClass = ua.NodeClass.Variable
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.Description = ua.LocalizedText("Specifies the default values for optional input arguments.")
    attrs.DisplayName = ua.LocalizedText("DefaultInputValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.String)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16306")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2000")
    node.BrowseName = ua.QualifiedName.from_string("ImageBMP")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=30")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An image encoded in BMP format.")
    attrs.DisplayName = ua.LocalizedText("ImageBMP")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2000")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=30")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2001")
    node.BrowseName = ua.QualifiedName.from_string("ImageGIF")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=30")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An image encoded in GIF format.")
    attrs.DisplayName = ua.LocalizedText("ImageGIF")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2001")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=30")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2002")
    node.BrowseName = ua.QualifiedName.from_string("ImageJPG")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=30")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An image encoded in JPEG format.")
    attrs.DisplayName = ua.LocalizedText("ImageJPG")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2002")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=30")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=2003")
    node.BrowseName = ua.QualifiedName.from_string("ImagePNG")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=30")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An image encoded in PNG format.")
    attrs.DisplayName = ua.LocalizedText("ImagePNG")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=2003")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=30")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16307")
    node.BrowseName = ua.QualifiedName.from_string("AudioDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=15")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An image encoded in PNG format.")
    attrs.DisplayName = ua.LocalizedText("AudioDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=16307")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=256")
    node.BrowseName = ua.QualifiedName.from_string("IdType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("The type of identifier used in a node id.")
    attrs.DisplayName = ua.LocalizedText("IdType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7591")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=256")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7591")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=256")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Numeric'),ua.LocalizedText('String'),ua.LocalizedText('Guid'),ua.LocalizedText('Opaque')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=7591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=7591")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=256")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=257")
    node.BrowseName = ua.QualifiedName.from_string("NodeClass")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A mask specifying the class of the node.")
    attrs.DisplayName = ua.LocalizedText("NodeClass")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=257")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11878")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=257")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=11878")
    node.BrowseName = ua.QualifiedName.from_string("EnumValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=257")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumValues")
    attrs.DataType = ua.NodeId.from_string("i=7594")
    value = []
    extobj = ua.EnumValueType()
    extobj.Value = 0
    extobj.DisplayName.Text = 'Unspecified'
    extobj.Description.Text = 'No classes are selected.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 1
    extobj.DisplayName.Text = 'Object'
    extobj.Description.Text = 'The node is an object.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 2
    extobj.DisplayName.Text = 'Variable'
    extobj.Description.Text = 'The node is a variable.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 4
    extobj.DisplayName.Text = 'Method'
    extobj.Description.Text = 'The node is a method.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 8
    extobj.DisplayName.Text = 'ObjectType'
    extobj.Description.Text = 'The node is an object type.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 16
    extobj.DisplayName.Text = 'VariableType'
    extobj.Description.Text = 'The node is an variable type.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 32
    extobj.DisplayName.Text = 'ReferenceType'
    extobj.Description.Text = 'The node is a reference type.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 64
    extobj.DisplayName.Text = 'DataType'
    extobj.Description.Text = 'The node is a data type.'
    value.append(extobj)
    extobj = ua.EnumValueType()
    extobj.Value = 128
    extobj.DisplayName.Text = 'View'
    extobj.Description.Text = 'The node is a view.'
    value.append(extobj)
    attrs.Value = ua.Variant(value, ua.VariantType.ExtensionObject)
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=11878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=11878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=11878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=257")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=94")
    node.BrowseName = ua.QualifiedName.from_string("PermissionType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=5")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("PermissionType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=94")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15030")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=94")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=5")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15030")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=94")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Browse'),ua.LocalizedText('ReadRolePermissions'),ua.LocalizedText('WriteAttribute'),ua.LocalizedText('WriteRolePermissions'),ua.LocalizedText('WriteHistorizing'),ua.LocalizedText('Read'),ua.LocalizedText('Write'),ua.LocalizedText('ReadHistory'),ua.LocalizedText('InsertHistory'),ua.LocalizedText('ModifyHistory'),ua.LocalizedText('DeleteHistory'),ua.LocalizedText('ReceiveEvents'),ua.LocalizedText('Call'),ua.LocalizedText('AddReference'),ua.LocalizedText('RemoveReference'),ua.LocalizedText('DeleteNode'),ua.LocalizedText('AddNode')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15030")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=94")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15031")
    node.BrowseName = ua.QualifiedName.from_string("AccessLevelType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=3")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AccessLevelType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15032")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15031")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=3")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15032")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15031")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('CurrentRead'),ua.LocalizedText('CurrentWrite'),ua.LocalizedText('HistoryRead'),ua.LocalizedText('Reserved'),ua.LocalizedText('HistoryWrite'),ua.LocalizedText('StatusWrite'),ua.LocalizedText('TimestampWrite')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15032")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15032")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15032")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15031")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15406")
    node.BrowseName = ua.QualifiedName.from_string("AccessLevelExType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AccessLevelExType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15406")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15407")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15406")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15407")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15406")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('CurrentRead'),ua.LocalizedText('CurrentWrite'),ua.LocalizedText('HistoryRead'),ua.LocalizedText('Reserved'),ua.LocalizedText('HistoryWrite'),ua.LocalizedText('StatusWrite'),ua.LocalizedText('TimestampWrite'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('Reserved'),ua.LocalizedText('NonatomicRead'),ua.LocalizedText('NonatomicWrite'),ua.LocalizedText('WriteFullArrayOnly')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15407")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15407")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15407")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15406")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15033")
    node.BrowseName = ua.QualifiedName.from_string("EventNotifierType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EventNotifierType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15033")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15034")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=15033")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15034")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=15033")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('SubscribeToEvents'),ua.LocalizedText('Reserved'),ua.LocalizedText('HistoryRead'),ua.LocalizedText('HistoryWrite')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15034")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15034")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15034")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15033")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=95")
    node.BrowseName = ua.QualifiedName.from_string("AccessRestrictionType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("AccessRestrictionType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=95")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=15035")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=95")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15035")
    node.BrowseName = ua.QualifiedName.from_string("OptionSetValues")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=95")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("OptionSetValues")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('SigningRequired'),ua.LocalizedText('EncryptionRequired'),ua.LocalizedText('SessionRequired')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=15035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=15035")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=95")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=96")
    node.BrowseName = ua.QualifiedName.from_string("RolePermissionType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("RolePermissionType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=96")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=97")
    node.BrowseName = ua.QualifiedName.from_string("DataTypeDefinition")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("DataTypeDefinition")
    attrs.IsAbstract = True
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=97")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=98")
    node.BrowseName = ua.QualifiedName.from_string("StructureType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=29")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=98")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14528")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=98")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=29")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14528")
    node.BrowseName = ua.QualifiedName.from_string("EnumStrings")
    node.NodeClass = ua.NodeClass.Variable
    node.ParentNodeId = ua.NodeId.from_string("i=98")
    node.ReferenceTypeId = ua.NodeId.from_string("i=46")
    node.TypeDefinition = ua.NodeId.from_string("i=68")
    attrs = ua.VariableAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumStrings")
    attrs.DataType = ua.NodeId(ua.ObjectIds.LocalizedText)
    attrs.Value = [ua.LocalizedText('Structure'),ua.LocalizedText('StructureWithOptionalFields'),ua.LocalizedText('Union')]
    attrs.ValueRank = 1
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14528")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=68")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=37")
    ref.SourceNodeId = ua.NodeId.from_string("i=14528")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=78")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=46")
    ref.SourceNodeId = ua.NodeId.from_string("i=14528")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=98")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=101")
    node.BrowseName = ua.QualifiedName.from_string("StructureField")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureField")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=101")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=99")
    node.BrowseName = ua.QualifiedName.from_string("StructureDefinition")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=97")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("StructureDefinition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=99")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=97")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=100")
    node.BrowseName = ua.QualifiedName.from_string("EnumDefinition")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=97")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumDefinition")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=100")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=97")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=296")
    node.BrowseName = ua.QualifiedName.from_string("Argument")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An argument for a method.")
    attrs.DisplayName = ua.LocalizedText("Argument")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=296")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7594")
    node.BrowseName = ua.QualifiedName.from_string("EnumValueType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A mapping between a value of an enumerated type and a name and description.")
    attrs.DisplayName = ua.LocalizedText("EnumValueType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=7594")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=102")
    node.BrowseName = ua.QualifiedName.from_string("EnumField")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=7594")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("EnumField")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=102")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7594")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12755")
    node.BrowseName = ua.QualifiedName.from_string("OptionSet")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("This abstract Structured DataType is the base DataType for all DataTypes representing a bit mask.")
    attrs.DisplayName = ua.LocalizedText("OptionSet")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12755")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12756")
    node.BrowseName = ua.QualifiedName.from_string("Union")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("This abstract DataType is the base DataType for all union DataTypes.")
    attrs.DisplayName = ua.LocalizedText("Union")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12756")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12877")
    node.BrowseName = ua.QualifiedName.from_string("NormalizedString")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A string normalized based on the rules in the unicode specification.")
    attrs.DisplayName = ua.LocalizedText("NormalizedString")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12877")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12878")
    node.BrowseName = ua.QualifiedName.from_string("DecimalString")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An arbitraty numeric value.")
    attrs.DisplayName = ua.LocalizedText("DecimalString")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12878")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12879")
    node.BrowseName = ua.QualifiedName.from_string("DurationString")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A period of time formatted as defined in ISO 8601-2000.")
    attrs.DisplayName = ua.LocalizedText("DurationString")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12879")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12880")
    node.BrowseName = ua.QualifiedName.from_string("TimeString")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A time formatted as defined in ISO 8601-2000.")
    attrs.DisplayName = ua.LocalizedText("TimeString")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12880")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12881")
    node.BrowseName = ua.QualifiedName.from_string("DateString")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A date formatted as defined in ISO 8601-2000.")
    attrs.DisplayName = ua.LocalizedText("DateString")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=12881")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=290")
    node.BrowseName = ua.QualifiedName.from_string("Duration")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=11")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A period of time measured in milliseconds.")
    attrs.DisplayName = ua.LocalizedText("Duration")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=290")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=11")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=294")
    node.BrowseName = ua.QualifiedName.from_string("UtcTime")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=13")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("A date/time value specified in Universal Coordinated Time (UTC).")
    attrs.DisplayName = ua.LocalizedText("UtcTime")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=294")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=13")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=295")
    node.BrowseName = ua.QualifiedName.from_string("LocaleId")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=12")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.Description = ua.LocalizedText("An identifier for a user locale.")
    attrs.DisplayName = ua.LocalizedText("LocaleId")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=295")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8912")
    node.BrowseName = ua.QualifiedName.from_string("TimeZoneDataType")
    node.NodeClass = ua.NodeClass.DataType
    node.ParentNodeId = ua.NodeId.from_string("i=22")
    node.ReferenceTypeId = ua.NodeId.from_string("i=45")
    attrs = ua.DataTypeAttributes()
    attrs.DisplayName = ua.LocalizedText("TimeZoneDataType")
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=45")
    ref.SourceNodeId = ua.NodeId.from_string("i=8912")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=22")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=128")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=96")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=96")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16131")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=128")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=121")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=97")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=97")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18178")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=121")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14844")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=101")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14844")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=101")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14844")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18181")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14844")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=122")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=99")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=99")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18184")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=122")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=123")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=123")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=100")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=123")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18187")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=123")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=298")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=298")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=296")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=298")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7650")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=298")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8251")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=7594")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=8251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7594")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=8251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7656")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8251")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14845")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=102")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14845")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=102")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14845")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14870")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14845")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12765")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12765")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12765")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12767")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12765")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12766")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12756")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12756")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12770")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12766")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8917")
    node.BrowseName = ua.QualifiedName.from_string("Default Binary")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=8912")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default Binary")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=8917")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8912")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=8917")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8914")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8917")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=16126")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=96")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=16126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=96")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=16126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=16127")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=16126")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14797")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=97")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14797")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=97")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14797")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18166")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14797")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14800")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=101")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14800")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=101")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14800")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18169")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14800")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14798")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=99")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14798")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=99")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14798")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18172")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14798")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14799")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14799")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=100")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14799")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=18175")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14799")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=297")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=296")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8285")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=297")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=7616")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=7594")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=7616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7594")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=7616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8291")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=7616")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=14801")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=102")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=14801")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=102")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=14801")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=14826")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=14801")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12757")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12757")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12757")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12759")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12757")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=12758")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12756")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=12758")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12756")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=12758")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12762")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=12758")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=8913")
    node.BrowseName = ua.QualifiedName.from_string("Default XML")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=8912")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default XML")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=8913")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8912")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=39")
    ref.SourceNodeId = ua.NodeId.from_string("i=8913")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8918")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=8913")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15062")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=96")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=96")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15062")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15063")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=97")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15063")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=97")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15063")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15065")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=101")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=101")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15065")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15066")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=99")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15066")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=99")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15066")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15067")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=100")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15067")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=100")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15067")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15081")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=296")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=296")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15081")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15082")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=7594")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=7594")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15082")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15083")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=102")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=102")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15083")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15084")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12755")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12755")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15084")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15085")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=12756")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15085")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=12756")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15085")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
   
    node = ua.AddNodesItem()
    node.RequestedNewNodeId = ua.NodeId.from_string("i=15086")
    node.BrowseName = ua.QualifiedName.from_string("Default JSON")
    node.NodeClass = ua.NodeClass.Object
    node.ParentNodeId = ua.NodeId.from_string("i=8912")
    node.ReferenceTypeId = ua.NodeId.from_string("i=38")
    node.TypeDefinition = ua.NodeId.from_string("i=76")
    attrs = ua.ObjectAttributes()
    attrs.DisplayName = ua.LocalizedText("Default JSON")
    attrs.EventNotifier = 0
    node.NodeAttributes = attrs
    server.add_nodes([node])
    refs = []
    ref = ua.AddReferencesItem()
    ref.IsForward = False
    ref.ReferenceTypeId = ua.NodeId.from_string("i=38")
    ref.SourceNodeId = ua.NodeId.from_string("i=15086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=8912")
    refs.append(ref)
    ref = ua.AddReferencesItem()
    ref.IsForward = True
    ref.ReferenceTypeId = ua.NodeId.from_string("i=40")
    ref.SourceNodeId = ua.NodeId.from_string("i=15086")
    ref.TargetNodeClass = ua.NodeClass.DataType
    ref.TargetNodeId = ua.NodeId.from_string("i=76")
    refs.append(ref)
    server.add_references(refs)
